@@ -41,8 +41,7 @@ pub trait TryIntoBytes {
   ///
   /// let bytes: Vec<u8> = vec_message.try_into_bytes().unwrap();
   /// ```
-  fn try_into_bytes<C: Array<Item = u8>>(self) -> Result<C, Self::Error>
-    where for<'a> &'a C: IntoIterator<Item = &'a u8>;
+  fn try_into_bytes<C: Array<Item = u8>>(self) -> Result<C, Self::Error>;
 }
 
 /// Errors encounterable serializing to bytes
@@ -52,16 +51,10 @@ pub enum MessageToBytesError {
   TooLong { capacity: usize, size: usize },
 }
 
-impl<P: Array<Item = u8>, O: Array<Item = u8>, Os: Array<Item = Opt<O>>> TryIntoBytes for Message<P, O, Os>
-  where for<'b> &'b P: IntoIterator<Item = &'b u8>,
-        for<'b> &'b O: IntoIterator<Item = &'b u8>,
-        for<'b> &'b Os: IntoIterator<Item = &'b Opt<O>>
-{
+impl<P: Array<Item = u8>, O: Array<Item = u8>, Os: Array<Item = Opt<O>>> TryIntoBytes for Message<P, O, Os> {
   type Error = MessageToBytesError;
 
-  fn try_into_bytes<C: Array<Item = u8>>(self) -> Result<C, Self::Error>
-    where for<'a> &'a C: IntoIterator<Item = &'a u8>
-  {
+  fn try_into_bytes<C: Array<Item = u8>>(self) -> Result<C, Self::Error> {
     let mut bytes = C::reserve(self.get_size());
     let size: usize = self.get_size();
 
